==> haskell-yaml-0.11.11.2-44-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-3sWHAw2GBnQ38IoWLlyh5J
key:                  yaml-0.11.11.2-3sWHAw2GBnQ38IoWLlyh5J
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  b54ed6eaadf4c110391cd711574029f0
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.2.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-3sWHAw2GBnQ38IoWLlyh5J
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh
    containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    libyaml-0.1.2-2wBmBh4ENS0IRhzdQzmaI8 mtl-2.2.2
    resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc template-haskell-2.18.0.0
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.11.2-58-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-5iEcWtzaUe01xKRCgCieOl
key:                  yaml-0.11.11.2-5iEcWtzaUe01xKRCgCieOl
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  d90cfcf3d4aa996e067e1e49cea6a599
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.2.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-5iEcWtzaUe01xKRCgCieOl
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    libyaml-0.1.4-D8tum3J3WUHA85IRg8YnYM mtl-2.2.2
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD template-haskell-2.18.0.0
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
